==> elasticloadbalancingv2-1.15.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/elasticloadbalancingv2/CfnListenerProps.java <==
package software.amazon.awscdk.services.elasticloadbalancingv2;

/**
 * Properties for defining a `AWS::ElasticLoadBalancingV2::Listener`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-elasticloadbalancingv2-listener.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.19.0 (build 7c562bc)", date = "2019-10-28T12:26:31.901Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
public interface CfnListenerProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::ElasticLoadBalancingV2::Listener.DefaultActions`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-elasticloadbalancingv2-listener.html#cfn-elasticloadbalancingv2-listener-defaultactions
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.Object getDefaultActions();

    /**
     * `AWS::ElasticLoadBalancingV2::Listener.LoadBalancerArn`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-elasticloadbalancingv2-listener.html#cfn-elasticloadbalancingv2-listener-loadbalancerarn
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getLoadBalancerArn();

    /**
     * `AWS::ElasticLoadBalancingV2::Listener.Port`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-elasticloadbalancingv2-listener.html#cfn-elasticloadbalancingv2-listener-port
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.Number getPort();

    /**
     * `AWS::ElasticLoadBalancingV2::Listener.Protocol`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-elasticloadbalancingv2-listener.html#cfn-elasticloadbalancingv2-listener-protocol
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getProtocol();

    /**
     * `AWS::ElasticLoadBalancingV2::Listener.Certificates`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-elasticloadbalancingv2-listener.html#cfn-elasticloadbalancingv2-listener-certificates
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.Object getCertificates();

    /**
     * `AWS::ElasticLoadBalancingV2::Listener.SslPolicy`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-elasticloadbalancingv2-listener.html#cfn-elasticloadbalancingv2-listener-sslpolicy
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getSslPolicy();

    /**
     * @return a {@link Builder} of {@link CfnListenerProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnListenerProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    public static final class Builder {
        private java.lang.Object defaultActions;
        private java.lang.String loadBalancerArn;
        private java.lang.Number port;
        private java.lang.String protocol;
        private java.lang.Object certificates;
        private java.lang.String sslPolicy;

        /**
         * Sets the value of DefaultActions
         * @param defaultActions `AWS::ElasticLoadBalancingV2::Listener.DefaultActions`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder defaultActions(software.amazon.awscdk.core.IResolvable defaultActions) {
            this.defaultActions = defaultActions;
            return this;
        }

        /**
         * Sets the value of DefaultActions
         * @param defaultActions `AWS::ElasticLoadBalancingV2::Listener.DefaultActions`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder defaultActions(java.util.List<java.lang.Object> defaultActions) {
            this.defaultActions = defaultActions;
            return this;
        }

        /**
         * Sets the value of LoadBalancerArn
         * @param loadBalancerArn `AWS::ElasticLoadBalancingV2::Listener.LoadBalancerArn`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder loadBalancerArn(java.lang.String loadBalancerArn) {
            this.loadBalancerArn = loadBalancerArn;
            return this;
        }

        /**
         * Sets the value of Port
         * @param port `AWS::ElasticLoadBalancingV2::Listener.Port`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder port(java.lang.Number port) {
            this.port = port;
            return this;
        }

        /**
         * Sets the value of Protocol
         * @param protocol `AWS::ElasticLoadBalancingV2::Listener.Protocol`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder protocol(java.lang.String protocol) {
            this.protocol = protocol;
            return this;
        }

        /**
         * Sets the value of Certificates
         * @param certificates `AWS::ElasticLoadBalancingV2::Listener.Certificates`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder certificates(software.amazon.awscdk.core.IResolvable certificates) {
            this.certificates = certificates;
            return this;
        }

        /**
         * Sets the value of Certificates
         * @param certificates `AWS::ElasticLoadBalancingV2::Listener.Certificates`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder certificates(java.util.List<java.lang.Object> certificates) {
            this.certificates = certificates;
            return this;
        }

        /**
         * Sets the value of SslPolicy
         * @param sslPolicy `AWS::ElasticLoadBalancingV2::Listener.SslPolicy`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder sslPolicy(java.lang.String sslPolicy) {
            this.sslPolicy = sslPolicy;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnListenerProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public CfnListenerProps build() {
            return new Jsii$Proxy(defaultActions, loadBalancerArn, port, protocol, certificates, sslPolicy);
        }
    }

    /**
     * An implementation for {@link CfnListenerProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnListenerProps {
        private final java.lang.Object defaultActions;
        private final java.lang.String loadBalancerArn;
        private final java.lang.Number port;
        private final java.lang.String protocol;
        private final java.lang.Object certificates;
        private final java.lang.String sslPolicy;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.defaultActions = this.jsiiGet("defaultActions", java.lang.Object.class);
            this.loadBalancerArn = this.jsiiGet("loadBalancerArn", java.lang.String.class);
            this.port = this.jsiiGet("port", java.lang.Number.class);
            this.protocol = this.jsiiGet("protocol", java.lang.String.class);
            this.certificates = this.jsiiGet("certificates", java.lang.Object.class);
            this.sslPolicy = this.jsiiGet("sslPolicy", java.lang.String.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(java.lang.Object defaultActions, java.lang.String loadBalancerArn, java.lang.Number port, java.lang.String protocol, java.lang.Object certificates, java.lang.String sslPolicy) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.defaultActions = java.util.Objects.requireNonNull(defaultActions, "defaultActions is required");
            this.loadBalancerArn = java.util.Objects.requireNonNull(loadBalancerArn, "loadBalancerArn is required");
            this.port = java.util.Objects.requireNonNull(port, "port is required");
            this.protocol = java.util.Objects.requireNonNull(protocol, "protocol is required");
            this.certificates = certificates;
            this.sslPolicy = sslPolicy;
        }

        @Override
        public java.lang.Object getDefaultActions() {
            return this.defaultActions;
        }

        @Override
        public java.lang.String getLoadBalancerArn() {
            return this.loadBalancerArn;
        }

        @Override
        public java.lang.Number getPort() {
            return this.port;
        }

        @Override
        public java.lang.String getProtocol() {
            return this.protocol;
        }

        @Override
        public java.lang.Object getCertificates() {
            return this.certificates;
        }

        @Override
        public java.lang.String getSslPolicy() {
            return this.sslPolicy;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("defaultActions", om.valueToTree(this.getDefaultActions()));
            obj.set("loadBalancerArn", om.valueToTree(this.getLoadBalancerArn()));
            obj.set("port", om.valueToTree(this.getPort()));
            obj.set("protocol", om.valueToTree(this.getProtocol()));
            if (this.getCertificates() != null) {
                obj.set("certificates", om.valueToTree(this.getCertificates()));
            }
            if (this.getSslPolicy() != null) {
                obj.set("sslPolicy", om.valueToTree(this.getSslPolicy()));
            }
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnListenerProps.Jsii$Proxy that = (CfnListenerProps.Jsii$Proxy) o;

            if (!defaultActions.equals(that.defaultActions)) return false;
            if (!loadBalancerArn.equals(that.loadBalancerArn)) return false;
            if (!port.equals(that.port)) return false;
            if (!protocol.equals(that.protocol)) return false;
            if (this.certificates != null ? !this.certificates.equals(that.certificates) : that.certificates != null) return false;
            return this.sslPolicy != null ? this.sslPolicy.equals(that.sslPolicy) : that.sslPolicy == null;
        }

        @Override
        public int hashCode() {
            int result = this.defaultActions.hashCode();
            result = 31 * result + (this.loadBalancerArn.hashCode());
            result = 31 * result + (this.port.hashCode());
            result = 31 * result + (this.protocol.hashCode());
            result = 31 * result + (this.certificates != null ? this.certificates.hashCode() : 0);
            result = 31 * result + (this.sslPolicy != null ? this.sslPolicy.hashCode() : 0);
            return result;
        }
    }
}

==> elasticloadbalancingv2-1.16.1.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/elasticloadbalancingv2/CfnListenerProps.java <==
package software.amazon.awscdk.services.elasticloadbalancingv2;

/**
 * Properties for defining a `AWS::ElasticLoadBalancingV2::Listener`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-elasticloadbalancingv2-listener.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.20.3 (build 26aa77c)", date = "2019-11-12T00:10:05.414Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.elasticloadbalancingv2.$Module.class, fqn = "@aws-cdk/aws-elasticloadbalancingv2.CfnListenerProps")
@software.amazon.jsii.Jsii.Proxy(CfnListenerProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
public interface CfnListenerProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::ElasticLoadBalancingV2::Listener.DefaultActions`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-elasticloadbalancingv2-listener.html#cfn-elasticloadbalancingv2-listener-defaultactions
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.Object getDefaultActions();

    /**
     * `AWS::ElasticLoadBalancingV2::Listener.LoadBalancerArn`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-elasticloadbalancingv2-listener.html#cfn-elasticloadbalancingv2-listener-loadbalancerarn
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getLoadBalancerArn();

    /**
     * `AWS::ElasticLoadBalancingV2::Listener.Port`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-elasticloadbalancingv2-listener.html#cfn-elasticloadbalancingv2-listener-port
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.Number getPort();

    /**
     * `AWS::ElasticLoadBalancingV2::Listener.Protocol`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-elasticloadbalancingv2-listener.html#cfn-elasticloadbalancingv2-listener-protocol
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getProtocol();

    /**
     * `AWS::ElasticLoadBalancingV2::Listener.Certificates`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-elasticloadbalancingv2-listener.html#cfn-elasticloadbalancingv2-listener-certificates
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    default java.lang.Object getCertificates() {
        return null;
    }

    /**
     * `AWS::ElasticLoadBalancingV2::Listener.SslPolicy`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-elasticloadbalancingv2-listener.html#cfn-elasticloadbalancingv2-listener-sslpolicy
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    default java.lang.String getSslPolicy() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnListenerProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnListenerProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    public static final class Builder {
        private java.lang.Object defaultActions;
        private java.lang.String loadBalancerArn;
        private java.lang.Number port;
        private java.lang.String protocol;
        private java.lang.Object certificates;
        private java.lang.String sslPolicy;

        /**
         * Sets the value of DefaultActions
         * @param defaultActions `AWS::ElasticLoadBalancingV2::Listener.DefaultActions`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder defaultActions(software.amazon.awscdk.core.IResolvable defaultActions) {
            this.defaultActions = defaultActions;
            return this;
        }

        /**
         * Sets the value of DefaultActions
         * @param defaultActions `AWS::ElasticLoadBalancingV2::Listener.DefaultActions`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder defaultActions(java.util.List<java.lang.Object> defaultActions) {
            this.defaultActions = defaultActions;
            return this;
        }

        /**
         * Sets the value of LoadBalancerArn
         * @param loadBalancerArn `AWS::ElasticLoadBalancingV2::Listener.LoadBalancerArn`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder loadBalancerArn(java.lang.String loadBalancerArn) {
            this.loadBalancerArn = loadBalancerArn;
            return this;
        }

        /**
         * Sets the value of Port
         * @param port `AWS::ElasticLoadBalancingV2::Listener.Port`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder port(java.lang.Number port) {
            this.port = port;
            return this;
        }

        /**
         * Sets the value of Protocol
         * @param protocol `AWS::ElasticLoadBalancingV2::Listener.Protocol`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder protocol(java.lang.String protocol) {
            this.protocol = protocol;
            return this;
        }

        /**
         * Sets the value of Certificates
         * @param certificates `AWS::ElasticLoadBalancingV2::Listener.Certificates`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder certificates(software.amazon.awscdk.core.IResolvable certificates) {
            this.certificates = certificates;
            return this;
        }

        /**
         * Sets the value of Certificates
         * @param certificates `AWS::ElasticLoadBalancingV2::Listener.Certificates`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder certificates(java.util.List<java.lang.Object> certificates) {
            this.certificates = certificates;
            return this;
        }

        /**
         * Sets the value of SslPolicy
         * @param sslPolicy `AWS::ElasticLoadBalancingV2::Listener.SslPolicy`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder sslPolicy(java.lang.String sslPolicy) {
            this.sslPolicy = sslPolicy;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnListenerProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public CfnListenerProps build() {
            return new Jsii$Proxy(defaultActions, loadBalancerArn, port, protocol, certificates, sslPolicy);
        }
    }

    /**
     * An implementation for {@link CfnListenerProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnListenerProps {
        private final java.lang.Object defaultActions;
        private final java.lang.String loadBalancerArn;
        private final java.lang.Number port;
        private final java.lang.String protocol;
        private final java.lang.Object certificates;
        private final java.lang.String sslPolicy;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.defaultActions = this.jsiiGet("defaultActions", java.lang.Object.class);
            this.loadBalancerArn = this.jsiiGet("loadBalancerArn", java.lang.String.class);
            this.port = this.jsiiGet("port", java.lang.Number.class);
            this.protocol = this.jsiiGet("protocol", java.lang.String.class);
            this.certificates = this.jsiiGet("certificates", java.lang.Object.class);
            this.sslPolicy = this.jsiiGet("sslPolicy", java.lang.String.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.Object defaultActions, final java.lang.String loadBalancerArn, final java.lang.Number port, final java.lang.String protocol, final java.lang.Object certificates, final java.lang.String sslPolicy) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.defaultActions = java.util.Objects.requireNonNull(defaultActions, "defaultActions is required");
            this.loadBalancerArn = java.util.Objects.requireNonNull(loadBalancerArn, "loadBalancerArn is required");
            this.port = java.util.Objects.requireNonNull(port, "port is required");
            this.protocol = java.util.Objects.requireNonNull(protocol, "protocol is required");
            this.certificates = certificates;
            this.sslPolicy = sslPolicy;
        }

        @Override
        public java.lang.Object getDefaultActions() {
            return this.defaultActions;
        }

        @Override
        public java.lang.String getLoadBalancerArn() {
            return this.loadBalancerArn;
        }

        @Override
        public java.lang.Number getPort() {
            return this.port;
        }

        @Override
        public java.lang.String getProtocol() {
            return this.protocol;
        }

        @Override
        public java.lang.Object getCertificates() {
            return this.certificates;
        }

        @Override
        public java.lang.String getSslPolicy() {
            return this.sslPolicy;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("defaultActions", om.valueToTree(this.getDefaultActions()));
            data.set("loadBalancerArn", om.valueToTree(this.getLoadBalancerArn()));
            data.set("port", om.valueToTree(this.getPort()));
            data.set("protocol", om.valueToTree(this.getProtocol()));
            if (this.getCertificates() != null) {
                data.set("certificates", om.valueToTree(this.getCertificates()));
            }
            if (this.getSslPolicy() != null) {
                data.set("sslPolicy", om.valueToTree(this.getSslPolicy()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-elasticloadbalancingv2.CfnListenerProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnListenerProps.Jsii$Proxy that = (CfnListenerProps.Jsii$Proxy) o;

            if (!defaultActions.equals(that.defaultActions)) return false;
            if (!loadBalancerArn.equals(that.loadBalancerArn)) return false;
            if (!port.equals(that.port)) return false;
            if (!protocol.equals(that.protocol)) return false;
            if (this.certificates != null ? !this.certificates.equals(that.certificates) : that.certificates != null) return false;
            return this.sslPolicy != null ? this.sslPolicy.equals(that.sslPolicy) : that.sslPolicy == null;
        }

        @Override
        public int hashCode() {
            int result = this.defaultActions.hashCode();
            result = 31 * result + (this.loadBalancerArn.hashCode());
            result = 31 * result + (this.port.hashCode());
            result = 31 * result + (this.protocol.hashCode());
            result = 31 * result + (this.certificates != null ? this.certificates.hashCode() : 0);
            result = 31 * result + (this.sslPolicy != null ? this.sslPolicy.hashCode() : 0);
            return result;
        }
    }
}
